@@ -13,7 +13,8 @@ import click
 import sqliteparser
 from tabulate import tabulate
 
-from . import Database, Schema, migrations
+from . import Database as ISqliteDatabase
+from . import Schema, migrations
 
 # Help strings used in multiple places.
 HELP_AUTO_TIMESTAMP_CREATE = (
@@ -45,6 +46,10 @@ HELP_PLAIN_FOREIGN_KEYS = (
 )
 
 
+def Database(*args, **kwargs):
+    return ISqliteDatabase(*args, use_epoch_timestamps=True, **kwargs)
+
+
 @click.group()
 def cli():
     pass
@@ -181,21 +186,16 @@ def main_delete(db_path, table, pk, *, where, no_confirm):
     """
     with Database(db_path) as db:
         if pk is not None:
-            try:
-                row = db.get_by_pk(table, pk)
-            except Exception:
-                # This can happen, e.g., if a timestamp column is invalidly formatted and
-                # the Python wrapper around sqlite3 chokes trying to convert it to a
-                # datetime.
-                print(
-                    "Unable to fetch row from database, possibly due to validation error."
-                )
-            else:
-                if row is None:
-                    print(f"Row {pk} not found in table {table!r}.")
-                    sys.exit(1)
+            row = db.get_by_pk(table, pk, get_related=True)
+            if row is None:
+                print(f"Row {pk} not found in table {table!r}.")
+                sys.exit(1)
 
-                prettyprint_row(row)
+            for key, value in row.items():
+                if isinstance(value, collections.OrderedDict):
+                    row[key] = get_column_as_string(value)
+
+            prettyprint_row(row)
 
             if not no_confirm:
                 print()
@@ -253,7 +253,7 @@ def _diff(db, schema, table, *, detect_renaming=True):
     diff = db.diff(schema, table=table, detect_renaming=detect_renaming)
     if not diff:
         print("Nothing to migrate: database matches schema.")
-        return None
+        return (None, None)
 
     tables_created = 0
     tables_dropped = 0
@@ -482,14 +482,7 @@ def _prompt_for_table(db, table, row, *, auto_timestamp):
         value = input("".join(prompt_builder)).strip()
 
         if not value:
-            if updating:
-                # If updating an existing row, skip empty values.
-                continue
-            else:
-                # If creating a new row, set the column to NULL if it is not a TEXT
-                # column or leave it as the empty string otherwise.
-                if column.definition.type != "TEXT":
-                    value = None
+            continue
 
         if value == "NULL":
             value = None if column.definition.type != "TEXT" else ""
@@ -945,6 +938,8 @@ def main_update(db_path, table, pk, payload, *, auto_timestamp):
     PAYLOAD should be a list of space-separated key-value pairs, e.g.
 
         isqlite update --db db.sqlite3 my_table 123 a=1 b=2
+
+    To set a column null, use the special NULL value.
     """
     if not payload:
         report_error_and_exit("payload must not be empty")
@@ -952,6 +947,10 @@ def main_update(db_path, table, pk, payload, *, auto_timestamp):
     payload_as_map = {}
     for key_value in payload:
         key, value = key_value.split("=", maxsplit=1)
+
+        if value == "NULL":
+            value = None
+
         payload_as_map[key] = value
 
     if auto_timestamp:
@@ -960,10 +959,13 @@ def main_update(db_path, table, pk, payload, *, auto_timestamp):
         auto_timestamp_columns = []
 
     with Database(db_path) as db:
-        db.update_by_pk(
+        updated = db.update_by_pk(
             table, pk, payload_as_map, auto_timestamp_columns=auto_timestamp_columns
         )
-        print(f"Row {pk} updated.")
+        if updated:
+            print(f"Row {pk} updated.")
+        else:
+            report_error_and_exit(f"row {pk} not found in table {table!r}.")
 
 
 def prettyprint_rows(rows, *, columns=[], hide=[], page=1):
