@@ -2,7 +2,7 @@ import collections
 import sqlite3
 import textwrap
 import warnings
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Sequence, Tuple, Union
 
 import sqliteparser
 from sqliteparser import quote
@@ -16,7 +16,8 @@ from .exceptions import (
 )
 from .schema import Diff, Schema, diff_schemas, diff_tables, rename_column
 
-CURRENT_TIMESTAMP_SQL = "STRFTIME('%Y-%m-%d %H:%M:%f', 'now')"
+CURRENT_ISO_8601_TIMESTAMP_SQL = "STRFTIME('%Y-%m-%d %H:%M:%f', 'now')"
+CURRENT_EPOCH_TIMESTAMP_SQL = "STRFTIME('%s', 'now')"
 AUTO_TIMESTAMP_DEFAULT = ("created_at", "last_updated_at")
 AUTO_TIMESTAMP_UPDATE_DEFAULT = ("last_updated_at",)
 
@@ -67,6 +68,7 @@ class Database:
         enforce_foreign_keys: bool = True,
         insert_auto_timestamp_columns: List[str] = [],
         update_auto_timestamp_columns: List[str] = [],
+        use_epoch_timestamps: bool = False,
     ) -> None:
         """
         Initialize a ``Database`` object.
@@ -99,15 +101,20 @@ class Database:
             file path.
         :param cached_statements: Passed on to ``sqlite3.connect``.
         :param enforce_foreign_keys: If true, foreign-key constraint enforcement will be
-            turned out with `PRAGMA foreign_keys = 1`.
+            turned out with ``PRAGMA foreign_keys = 1``.
         :param insert_auto_timestamp_columns: A default value for
             ``auto_timestamp_columns`` in ``insert`` and ``insert_many``. Usually set to
             ``["created_at", "last_updated_at"]`` in conjunction with a schema defined
-            using ``AutoTable``.
+            using ``AutoTable``. It is recommended to set ``use_epoch_timestamps`` to
+            ``True`` if using this parameter.
         :param update_auto_timestamp_columns: A default value for
             ``auto_timestamp_columns`` in ``update``. Usually set to
             ``["last_updated_at"]`` in conjunction with a schema defined using
-            ``AutoTable``.
+            ``AutoTable``. It is recommended to set ``use_epoch_timestamps`` to ``True``
+            if using this parameter.
+        :param use_epoch_timestamps: Store ``auto_timestamp_columns`` as seconds since
+            the Unix epoch instead of as ISO 8601 datetime strings. Recommended setting
+            is ``True``, but default is ``False`` for backwards compatibility.
         """
         # Validate arguments.
         if readonly is not None:
@@ -132,6 +139,11 @@ class Database:
 
         self.insert_auto_timestamp_columns = insert_auto_timestamp_columns
         self.update_auto_timestamp_columns = update_auto_timestamp_columns
+        self.current_timestamp_sql = (
+            CURRENT_EPOCH_TIMESTAMP_SQL
+            if use_epoch_timestamps
+            else CURRENT_ISO_8601_TIMESTAMP_SQL
+        )
 
         self.connection = sqlite3.connect(
             path,
@@ -167,7 +179,7 @@ class Database:
         values: Dict[str, Any] = {},
         limit: Optional[int] = None,
         offset: Optional[int] = None,
-        order_by: Optional[str] = None,
+        order_by: Optional[Union[Tuple[str], str]] = None,
         descending: Optional[bool] = None,
         get_related: Union[List[str], bool] = [],
     ) -> Rows:
@@ -190,7 +202,7 @@ class Database:
             used in conjunction with ``limit`` for pagination.
         :param order_by: If not None, order the results by this column. Order is
             ascending (smallest values first) by default; for descending order, pass
-            ``descending=True``.
+            ``descending=True``. To order by multiple columns, pass in a tuple.
         :param descending: If true, return results in descending order instead of
             ascending.
         :param get_related: A list of foreign-key columns of the table to be retrieved
@@ -200,10 +212,10 @@ class Database:
         """
         if order_by:
             if isinstance(order_by, (tuple, list)):
-                order_by = ", ".join(order_by)
+                order_by = ", ".join(map(quote, order_by))
 
             direction = "DESC" if descending is True else "ASC"
-            order_clause = f"ORDER BY {quote(order_by)} {direction}"
+            order_clause = f"ORDER BY {order_by} {direction}"
         else:
             if descending is not None:
                 raise ISqliteApiError(
@@ -258,7 +270,7 @@ class Database:
         columns: List[str] = [],
         where: str = "",
         values: Dict[str, Any] = {},
-        order_by: Optional[str] = None,
+        order_by: Optional[Union[Tuple[str], str]] = None,
         descending: Optional[bool] = None,
         get_related: Union[List[str], bool] = [],
     ) -> Optional[Row]:
@@ -421,7 +433,7 @@ class Database:
         extra_columns_list = []
         for column in auto_timestamp_columns_list:
             keys.append(column)
-            extra_columns_list.append(CURRENT_TIMESTAMP_SQL)
+            extra_columns_list.append(self.current_timestamp_sql)
 
         if extra_columns_list:
             extra_columns = (", " if data else "") + ", ".join(extra_columns_list)
@@ -499,7 +511,7 @@ class Database:
         extra_columns_list = []
         for column in auto_timestamp_columns_list:
             keys.append(column)
-            extra_columns_list.append(CURRENT_TIMESTAMP_SQL)
+            extra_columns_list.append(self.current_timestamp_sql)
 
         if extra_columns_list:
             extra_columns = (", " if data else "") + ", ".join(extra_columns_list)
@@ -557,7 +569,7 @@ class Database:
             updates_list.append(f"{quote(key)} = :{placeholder}")
 
         for column in auto_timestamp_columns_list:
-            updates_list.append(f"{quote(column)} = {CURRENT_TIMESTAMP_SQL}")
+            updates_list.append(f"{quote(column)} = {self.current_timestamp_sql}")
 
         if not updates_list:
             raise ISqliteError(
@@ -626,6 +638,23 @@ class Database:
         pk_column = f"{quote(table)}.rowid"
         return self.delete(table, where=f"{pk_column} = :pk", values={"pk": pk})
 
+    def delete_many_by_pks(self, table: str, pks: Sequence[int]) -> None:
+        """
+        Delete multiple rows.
+
+        :param table: The database table. WARNING: This value is directly interpolated
+            into the SQL statement. Do not pass untrusted input, to avoid SQL injection
+            attacks.
+        :param pks: The list of primary keys of the rows to delete. If the list is
+            empty, this method is a no-op.
+        """
+        if len(pks) == 0:
+            return
+
+        pk_column = f"{quote(table)}.rowid"
+        markers = ",".join("?" * len(pks))
+        return self.delete(table, where=f"{pk_column} IN ({markers})", values=pks)  # type: ignore
+
     def sql(
         self,
         query: str,
